@@ -5,13 +5,13 @@
 SEXP bernoulliprobrandom(SEXP patterns, SEXP outcomex,SEXP lambdacoef, 
 	SEXP gh, SEXP momentdata, SEXP probit)
 {
-	SEXP ans;
+	SEXP ans, temp;
 	int irow, outcome, index, noutcomes, nrows, ipoint, npoints, level2size, ilambda, lprobit, *rpatterns = INTEGER(patterns);
-	double  *routcomex = REAL(outcomex), *rans,
+	double  *routcomex = REAL(outcomex), *rans, *rtemp,
 		neww,newp, *rmomentdata=REAL(momentdata),
 		*rgh=REAL(gh),*rlambdacoef=REAL(lambdacoef);
-	double product, sum, myoutcomex, myoutcomep;
-	
+	double onesum, sum, myoutcomex, myoutcomep, maxtemp;
+
 	lprobit = asLogical(probit);
 	
 	noutcomes = LENGTH(outcomex);
@@ -23,6 +23,9 @@ SEXP bernoulliprobrandom(SEXP patterns, SEXP outcomex,SEXP lambdacoef,
 	
 	rans = REAL(ans);
 	
+	PROTECT(temp = allocVector(REALSXP,npoints));
+
+	 rtemp = REAL(temp);	
 	
 	for (irow=0; irow < nrows; irow++) {
 		/* Rprintf("irow  %d\n",irow); */
@@ -36,28 +39,34 @@ SEXP bernoulliprobrandom(SEXP patterns, SEXP outcomex,SEXP lambdacoef,
 				newp*newp/2.0;
 			/* Rprintf("newp,neww  %f,%f\n",newp,neww); */
 			ilambda=0;
-			product=1.0;
+			onesum=0.0;
 			for (outcome=0; outcome <noutcomes; outcome++) {
 				/* calculate outcome probability for this outcome */
 				myoutcomex = routcomex[outcome]+
 					rlambdacoef[ilambda]*newp;
 				if (lprobit)
-					myoutcomep=pnorm(myoutcomex,0,1,TRUE,FALSE);
+					myoutcomep=pnorm(myoutcomex,0,1,TRUE,TRUE);
 				else
-					myoutcomep=1.0/(1+exp(-myoutcomex));
+					myoutcomep=-log(1+exp(-myoutcomex));
 				ilambda=(ilambda+1) % level2size;				
 				/* update likelihood for this observation */
 			/*  Rprintf("myoutcomep  %f\n",myoutcomep); */
 				index = irow+outcome*nrows;
 				if (rpatterns[index]!=NA_INTEGER) {
-				  if (rpatterns[index]==1) product = product*myoutcomep;
-				  else product = product*(1-myoutcomep); 
+				  if (rpatterns[index]==1) onesum = onesum+myoutcomep;
+				  else onesum = onesum+log(1-exp(myoutcomep)); 
 				}
 			}
-			sum=sum+product*exp(neww);
+			rtemp[ipoint] = onesum+neww;
 		}
-		rans[irow]=sum;
+		maxtemp = R_NegInf;
+		for (ipoint=0; ipoint < npoints; ipoint++)
+		  if(rtemp[ipoint] > maxtemp) maxtemp = rtemp[ipoint];
+		sum = 0.0;
+		for (ipoint=0; ipoint < npoints; ipoint++)
+		  sum = sum+exp(rtemp[ipoint]-maxtemp);
+		rans[irow]=maxtemp+log(sum);
 	}
-	UNPROTECT(1);		
+	UNPROTECT(2);		
 	return ans;
 }
